streamlifecycle

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 13, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewTextStream

func NewTextStream(ctx context.Context, opts sigma.Options) (context.Context, *sigma.Stream, sigma.StreamWriter, func())

NewTextStream creates a sigma stream whose request context is canceled when the consumer closes the stream or the stream naturally finishes.

Types

This section is empty.

Jump to